
API Documentation
=================

Project Configuration Primitives
--------------------------------

.. toctree::

    tendril.entities.projects.eda

EDA Symbol Related Primitives
-----------------------------

.. toctree::

    tendril.entities.edasymbols
    tendril.entities.edasymbols.base
    tendril.entities.edasymbols.generator

EDA Symbol Library Infrastructure
---------------------------------

.. toctree::

    tendril.libraries.edasymbols
    tendril.libraries.edasymbols.base
    tendril.libraries.edasymbols.manager

Provided Schema Definitions
---------------------------

.. toctree::

   tendril.schema.edaprojects
   tendril.schema.edasymbols

Related Configuration Options
-----------------------------

.. automodule:: tendril.config.eda
    :members:
    :undoc-members:
    :show-inheritance:
